@@ -22,9 +22,24 @@ use constant DEBUG => $ENV{SBOM_DEBUG} || 0;
 # TODO Incomplete
 
 around BUILDARGS => sub {
+
     my ($orig, $class, @args) = @_;
-    return {id => $args[0]} if @args == 1 && !ref $args[0];
+
+    if (@args == 1 && defined $args[0] && !ref $args[0]) {
+
+        my $license = $args[0];
+        $license =~ s/^\s+|\s+$//g;
+
+        if ($license =~ /(\bWITH\b|\bOR\b|\bAND\b)/i) {
+            return {expression => $license};
+        }
+        else {
+            return {id => $license};
+        }
+    }
+
     return $class->$orig(@args);
+
 };
 
 extends 'SBOM::CycloneDX::Base';
@@ -47,6 +62,12 @@ has text            => (is => 'rw', isa => InstanceOf ['SBOM::CycloneDX::Attachm
 has url             => (is => 'rw', isa => Str, trigger => 1);
 has expression      => (is => 'rw', isa => Str);    # TODO check SPDX expression
 
+has expression_details => (
+    is      => 'rw',
+    isa     => ArrayLike [InstanceOf ['SBOM::CycloneDX::License::ExpressionDetail']],
+    default => sub { SBOM::CycloneDX::List->new }
+);
+
 has licensing => (
     is      => 'rw',
     isa     => InstanceOf ['SBOM::CycloneDX::License::Licensing'],
@@ -64,7 +85,7 @@ sub _trigger_id {
 
     my ($self) = @_;
 
-    if ($self->id && $self->id =~ /(WITH|AND|OR)/) {
+    if ($self->id && $self->id =~ /(\bWITH\b|\bOR\b|\bAND\b)/i) {
         DEBUG and say STDERR '-- Detected SPDX expression';
         $self->expression($self->id);
         $self->{id} = undef;
@@ -108,12 +129,13 @@ sub TO_JSON {
         $json->{license}->{id}   = $spdx_license if $spdx_license;
         $json->{license}->{name} = $license_name if $license_name;
 
-        $json->{license}->{'bom-ref'}       = $self->bom_ref         if $self->bom_ref;
-        $json->{license}->{acknowledgement} = $self->acknowledgement if $self->acknowledgement;
-        $json->{license}->{text}            = $self->text            if $self->text;
-        $json->{license}->{url}             = $self->url             if $self->url;
-        $json->{license}->{properties}      = $self->properties      if @{$self->properties};
-        $json->{license}->{licensing}       = $self->licensing       if %{$self->licensing->TO_JSON};
+        $json->{license}->{'bom-ref'}         = $self->bom_ref            if $self->bom_ref;
+        $json->{license}->{acknowledgement}   = $self->acknowledgement    if $self->acknowledgement;
+        $json->{license}->{text}              = $self->text               if $self->text;
+        $json->{license}->{url}               = $self->url                if $self->url;
+        $json->{license}->{properties}        = $self->properties         if @{$self->properties};
+        $json->{license}->{licensing}         = $self->licensing          if %{$self->licensing->TO_JSON};
+        $json->{license}->{expressionDetails} = $self->expression_details if @{$self->expression_details};
 
     }
 
@@ -141,6 +163,15 @@ SBOM::CycloneDX::License - Specifies the details and attributes related to a sof
 
     $license = SBOM::CycloneDX::License->new('MIT');
 
+    # SPDX license expression
+
+    $license = SBOM::CycloneDX::License->new(
+        expression => 'MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)'
+    );
+
+    # or
+
+    $license = SBOM::CycloneDX::License->new('MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)');
 
     # Non-SPDX license
 
@@ -165,13 +196,13 @@ and implements the following new ones.
 
 =over
 
-=item SBOM::CycloneDX::License->new( $id | %PARAMS )
+=item SBOM::CycloneDX::License->new( $id | $expression | %PARAMS )
 
 Properties:
 
 =over
 
-=item * C<bom_ref>, An optional identifier which can be used to reference the license
+=item * C<bom_ref>, An identifier which can be used to reference the license
 elsewhere in the BOM. Every bom-ref must be unique within the BOM.
 
 Value SHOULD not start with the BOM-Link intro C<urn:cdx:> to avoid conflicts with BOM-Links.
@@ -183,12 +214,16 @@ one of the enumeration of valid SPDX license identifiers defined in L<SBOM::Cycl
 
 Refer to L<https://spdx.org/specifications> for syntax requirements.
 
+=item * C<expression_details>, Details for parts of the C<expression>.
+
+See L<SBOM::CycloneDX::License::ExpressionDetail>
+
 =item * C<name>, The name of the license. This may include the name of a commercial
 or proprietary license or an open source license that may not be defined by SPDX.
 
 =item * C<acknowledgement>, 
 
-=item * C<text>, An optional way to include the textual content of a license.
+=item * C<text>, An way to include the textual content of a license.
 See L<SBOM::CycloneDX::Attachment>
 
 =item * C<url>, The URL to the license file. If C<1> is provided, the license URL is
@@ -245,6 +280,18 @@ registration is optional. See L<SBOM::CycloneDX::Property>
 
 =item $license->expression
 
+    # SPDX license expression
+
+    $license = SBOM::CycloneDX::License->new(
+        expression => 'MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)'
+    );
+
+    # or
+
+    $license = SBOM::CycloneDX::License->new('MIT AND (LGPL-2.1-or-later OR BSD-3-Clause)');
+
+=item $license->expression_details
+
 =item $license->licensing
 
     $license->licensing->alt_ids(['acme', 'acme-license']);
@@ -293,7 +340,7 @@ L<https://github.com/giterlizzi/perl-SBOM-CycloneDX>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is copyright (c) 2025 by Giuseppe Di Terlizzi.
+This software is copyright (c) 2025-2026 by Giuseppe Di Terlizzi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
